@@ -1,37 +1,23 @@
 /*
-    Copyright 2012 Lukáš Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2012 Lukáš Tinkl <ltinkl@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef SOLID_BACKENDS_UDISKS2_H
 #define SOLID_BACKENDS_UDISKS2_H
 
-#include <QMetaType>
+#include <QCoreApplication>
+#include <QDBusAbstractInterface>
 #include <QDBusObjectPath>
 #include <QDBusPendingReply>
 #include <QDBusReply>
-#include <QDBusAbstractInterface>
+#include <QList>
+#include <QMap>
+#include <QMetaType>
 #include <QPointer>
-#include <QCoreApplication>
 #include <QTimer>
 #include <QVariant>
-#include <QMap>
-#include <QList>
 
 typedef QMap<QString, QVariantMap> VariantMapMap;
 Q_DECLARE_METATYPE(VariantMapMap)
@@ -39,13 +25,16 @@ Q_DECLARE_METATYPE(VariantMapMap)
 typedef QMap<QDBusObjectPath, VariantMapMap> DBUSManagerStruct;
 Q_DECLARE_METATYPE(DBUSManagerStruct)
 
+// clang-format off
+
 /* UDisks2 */
 #define UD2_DBUS_SERVICE                 "org.freedesktop.UDisks2"
 #define UD2_DBUS_PATH                    "/org/freedesktop/UDisks2"
 #define UD2_UDI_DISKS_PREFIX             "/org/freedesktop/UDisks2"
 #define UD2_DBUS_PATH_MANAGER            "/org/freedesktop/UDisks2/Manager"
-#define UD2_DBUS_PATH_DRIVES             "/org/freedesktop/UDisks2/drives/"
+#define UD2_DBUS_PATH_DRIVES             "/org/freedesktop/UDisks2/drives"
 #define UD2_DBUS_PATH_JOBS               "/org/freedesktop/UDisks2/jobs/"
+#define UD2_DBUS_PATH_BLOCKDEVICES       "/org/freedesktop/UDisks2/block_devices"
 #define DBUS_INTERFACE_PROPS             "org.freedesktop.DBus.Properties"
 #define DBUS_INTERFACE_INTROSPECT        "org.freedesktop.DBus.Introspectable"
 #define DBUS_INTERFACE_MANAGER           "org.freedesktop.DBus.ObjectManager"
